%bcond_with check

Summary:	Command line tools to read and edit EXIF extensions in JPEG files
Name:		jhead
Version:	3.06.0.1
Release:	%mkrel 1
License:	Public Domain
Group:		Graphics/Utilities
URL:		http://www.sentex.net/~mwandel/jhead/
Source0:	https://codeload.github.com/Matthias-Wandel/jhead/tar.gz/refs/tags/%{version}#/jhead-%{version}.tar.gz
%if %{with check}
BuildRequires:	jpeg-progs
BuildRequires:	imagemagick
%endif

# Without jpegtran the nicest features will not work
Requires:	jpeg-progs


%description
Most digital cameras produce EXIF files, which are JPEG files with extra tags
that contain information about the image.

In contrary to the tools "exif" and "gexif" (and all other libexif-based tools
as "gphoto2") this tool gives a much easier readable summary of camera settings
(shutter speed in 1/x sec, focal length (also the 35-mm camera equivalent),
focal distance, ...), EXIF header manipulation as stripping off the thumbnail
and other info not needed, stripping off the complete header, applying
arbitrary conversion tools to the JPEG image and conserving the header,
renaming JPEG images with the capture date stored in the header, and even
turning the images upright when the camera has an orientation sensor (as Canon
Digital IXUS 400) ...

The tool is very compact, the executable has only a size of around 35 kb, the
whole package (with documentation) occupies 60 kb.

See %{_docdir}/jhead/usage.html for how to use this program.

%prep
%setup -q
%autopatch -p1

sed -i -e '/dpkg-buildflags/d' makefile

%build
%make_build CFLAGS="%{optflags}" LDFLAGS="%{ldflags}"

%install
install -Dpm0755 jhead %{buildroot}%{_bindir}/jhead
install -Dpm0644 jhead.1 %{buildroot}%{_mandir}/man1/jhead.1

%if %{with check}
%check
cd tests
sh ./runtests
diff expected-txt results-txt
cd..
%endif

%files
%doc readme.txt usage.html changes.txt
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*


%changelog
* Tue Jun 29 2021 wally <wally> 3.06.0.1-1.mga7
+ Revision: 1734211
- new version 3.06.0.1 to fix several security issues (mga#29053)

* Fri Dec 27 2019 wally <wally> 3.04-1.mga7
+ Revision: 1470200
- new version 3.04 to fix CVE-2019-19035, CVE-2019-1010301 and CVE-2019-1010302 (mga#25938)

* Sat Mar 16 2019 wally <wally> 3.03-1.mga7
+ Revision: 1377848
- new version 3.03
- add Debian patches (via Fedora)

* Sun Nov 11 2018 daviddavid <daviddavid> 3.00-7.mga7
+ Revision: 1329525
- rename CVE-2018-16554.patch to CVE-2018-17088.patch, because
  it is in fact fix of boo#1108672
- buffer overflow fix (boo#1108480) CVE-2018-16554.patch

* Sat Oct 13 2018 daviddavid <daviddavid> 3.00-6.mga7
+ Revision: 1319989
- add patch to fix CVE-2018-16554 (mga#23676)

* Sun Sep 23 2018 umeabot <umeabot> 3.00-5.mga7
+ Revision: 1298376
- Mageia 7 Mass Rebuild

* Sun Feb 11 2018 wally <wally> 3.00-4.mga7
+ Revision: 1200525
- add patch from SUSE to fix heap buffer overflow (CVE-2018-6612, mga#22565)

* Sun Apr 02 2017 wally <wally> 3.00-3.mga6
+ Revision: 1095611
- add patch from Google (via Debian) to fix CVE-2016-3822 (mga#20616)

* Thu Feb 11 2016 umeabot <umeabot> 3.00-2.mga6
+ Revision: 954685
- Mageia 6 Mass Rebuild

* Sun Jun 21 2015 wally <wally> 3.00-1.mga6
+ Revision: 837874
- new version 3.00

* Wed Oct 15 2014 umeabot <umeabot> 2.97-4.mga5
+ Revision: 742153
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.97-3.mga5
+ Revision: 680809
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 2.97-2.mga4
+ Revision: 523165
- Mageia 4 Mass Rebuild

* Fri Mar 29 2013 wally <wally> 2.97-1.mga3
+ Revision: 406508
- new version 2.97

* Thu Jan 24 2013 fwang <fwang> 2.96-2.mga3
+ Revision: 391853
- update rpm group
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jun 26 2012 wally <wally> 2.96-1.mga3
+ Revision: 264045
- new version 2.96

* Tue May 29 2012 wally <wally> 2.95-1.mga3
+ Revision: 249286
- new version 2.95
- clean .spec

* Sat Mar 03 2012 wally <wally> 2.94-2.mga2
+ Revision: 217146
- improve ldflags patch (got hint from Oden/MDV)
- clean .spec a bit

* Fri Mar 02 2012 wally <wally> 2.94-1.mga2
+ Revision: 216833
- new version 2.94
- build with ldflags (add P0)

* Wed Dec 07 2011 wally <wally> 2.93-1.mga2
+ Revision: 178397
- new version 2.93

* Wed Sep 14 2011 wally <wally> 2.90-3.mga2
+ Revision: 143549
- clean .spec a bit
- imported package jhead

